=========
indiapins
=========


.. image:: https://img.shields.io/pypi/v/indiapins.svg
        :target: https://pypi.python.org/pypi/indiapins

.. image:: https://img.shields.io/travis/pawangeek/indiapins.svg
        :target: https://travis-ci.com/pawangeek/indiapins

.. image:: https://readthedocs.org/projects/indiapins/badge/?version=latest
        :target: https://indiapins.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/github/license/pawangeek/indiapins.svg

.. image:: https://img.shields.io/pypi/pyversions/indiapins.svg


.. image:: https://pyup.io/repos/github/pawangeek/indiapins/shield.svg
     :target: https://pyup.io/repos/github/pawangeek/indiapins/
     :alt: Updates



Python package for mapping pins to the place where it belong


* Free software: MIT license
* Documentation: https://indiapins.readthedocs.io.
* Github Repo: https://github.com/pawangeek/indiapins

Features
--------

* TODO
